logging_drop_indent: Remove global indent for logging

View source: R/logging.R

logging_drop_indentR Documentation

Remove global indent for logging

Description

Change a global option that controls indentation for MBG package logging

Usage

logging_drop_indent()

Details

Decreases the MbgLoggingIndent option, with default of zero if not set


mbg documentation built on March 11, 2026, 1:07 a.m.